<?php
	/*------------------------------------------------------------
		Table of Contents:
			- Navigation
			- Display Top Level Category
			- Post Snippet
			- Post Snippet Button
			- Comments
	------------------------------------------------------------*/

	/*------------------------------------*\
	-------- Gravatar From Email Address
	\*------------------------------------*/
	function show_gravatar($email, $img_size = 40) {
		$gravatar_url = "http://www.gravatar.com/avatar/" . md5( strtolower( trim( $email ) ) ) . "?&s=" . $img_size;

		echo '<img src="' . $gravatar_url . '" />';
	}



	/*------------------------------------*\
	-------- Navigation
	\*------------------------------------*/
	add_action('init', 'register_navs');

	function register_navs() {
		register_nav_menus(
			array(
				'site-nav' => __('Site Navigation')
			)
		);
	}
	


	/*------------------------------------*\
	-------- Is Home Class
	\*------------------------------------*/
	function home_nav_current_link() {
		if (is_front_page()) {
			return ' current-menu-item';
		}
	}



	/*------------------------------------*\
	-------- Display Top Level Category
	\*------------------------------------*/
	function top_level_category() {
		$parents_category = '';

		foreach((get_the_category()) as $category) {
			if ($category->category_parent == 0) {
				$parents_category .= ' <a class="category-link" href="' . get_category_link($category->cat_ID) . '" title="' . $category->name . '">' . $category->name . '</a>, ';
			}
		}

		echo substr($parents_category, 0, -2);
	}



	/*------------------------------------*\
	-------- Post Thumbnail
	\*------------------------------------*/
	add_theme_support('post-thumbnails');
	set_post_thumbnail_size(800);

	function post_snippet_thumbnail() {
		if(is_single()) {
			echo get_the_post_thumbnail();
		}else {
			echo '<a class="thumb-wrap" href="' . get_permalink() . '">' . get_the_post_thumbnail() . '</a>';
		}
	}



	/*------------------------------------*\
	-------- Post Title
	\*------------------------------------*/
	function post_snippet_title() {
		if(is_single()) {
			echo '<h1>' . get_the_title() . '</h1>';
		}else {
			echo '<h2><a href="' . get_permalink() . '">' . get_the_title() . '</a></h2>';
		}
	}



	/*------------------------------------*\
	-------- Post Excerpt
	\*------------------------------------*/
	function new_excerpt_more($more) {
		return '...';
	}

	function custom_excerpt_length($length) {
		return 54;
	}

	add_filter('excerpt_length', 'custom_excerpt_length', 999);
	add_filter('excerpt_more', 'new_excerpt_more');

	function freon_post_excerpt() {
		if(is_single()) {
			the_content();
		}else {
			the_excerpt();
		}
	}

	function freon_social_share() {
		if(is_single()) {
?>
			<div class="post-snippet--share">
				<div class="post-snippet--share-single">
					<a href="https://twitter.com/share" class="twitter-share-button" data-via="SebKayDesign">Tweet</a>
				</div><!--end .post-snippet-share-single-->

				<div class="post-snippet--share-single">
					<div class="fb-share-button" data-href="<?php the_permalink(); ?>" data-type="button_count"></div>
				</div><!--end .post-snippet-share-single-->

				<div class="post-snippet--share-single">
					<div class="g-plus" data-action="share" data-annotation="bubble"></div>
				</div><!--end .post-snippet-share-single-->
			</div><!--end .post-snippet-share-->
<?php
		}
	}



	/*------------------------------------*\
	-------- Post Snippet
	\*------------------------------------*/
	function freon_post_snippet() {
?>
		<article class="post-snippet">
			<figure class="post-snippet--thumb">
				<?php post_snippet_thumbnail(); ?>
			</figure><!--end .post-snippet--thumb-->

			<div class="post-snippet--content">
				<?php post_snippet_title(); ?>

				<div class="post-snippet--meta-share">
					<p class="post-snippet--meta">
						By <?php the_author_posts_link(); ?>
						 on <time datetime="<?php the_time('Y-j-d'); ?>"><?php the_time('jS F, Y'); ?></time>
						 | <a href="<?php comments_link(); ?>"><?php comments_number(); ?></a>
					</p>

					<?php freon_social_share(); ?>
				</div><!--end .post-snippet-meta-share-->

				<?php freon_post_excerpt(); ?>
			</div><!--end .post-snippet-content-->
		</article><!--end .post-snippet-->
<?php
	}



	/*------------------------------------*\
	-------- Limit Search To Posts
	\*------------------------------------*/
	function search_filter($query) {
		if ($query->is_search) {
			$query->set('post_type', 'post');
		}

		return $query;
	}

	add_filter('pre_get_posts','search_filter');



	/*------------------------------------*\
	-------- Comments (Single Comment)
	\*------------------------------------*/
	function freon_comment($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		extract($args, EXTR_SKIP);
?>
		<div id="comment-<?php comment_id(); ?>" <?php comment_class('user-comments--single-comment'); ?>>
			<aside class="user-comments--avatar">
				<?php
					if(get_comment_author_url()) {
						$comment_author_url = get_comment_author_url();
						echo '<a href="' . $comment_author_url . '">' . get_avatar($comment->comment_author_email, $size = '85') . '</a>';
					}else {
						echo get_avatar($comment->comment_author_email, $size = '85');
					}
				?>
			</aside>

			<article class="user-comments--comment-content">
				<?php if($comment->comment_approved == '0') { ?>
					<div class="alert-info">
						<p>Your comment is currently <strong>in moderation</strong>.</p>
					</div><!--end .alert-info-->
				<?php } ?>
				
				<p class="user-comments--author-info">
					<?php comment_author_link(); ?> / 
					<?php comment_date('F jS Y'); ?>, <?php comment_time(); ?> / 
					<span id="reply"><?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span>
				</p>

				<?php echo apply_filters('the_content', $comment->comment_content); ?>
			</article>
		</div><!--end .comment-->
<?php
	}
?>